@@ -4,7 +4,9 @@ from symphony.bdk.core.retry import retry
 from symphony.bdk.core.retry.strategy import read_datafeed_retry
 from symphony.bdk.core.service.datafeed.abstract_datafeed_loop import AbstractDatafeedLoop
 from symphony.bdk.core.service.datafeed.exception import EventError
-from symphony.bdk.core.service.datafeed.on_disk_datafeed_id_repository import OnDiskDatafeedIdRepository
+from symphony.bdk.core.service.datafeed.on_disk_datafeed_id_repository import (
+    OnDiskDatafeedIdRepository,
+)
 
 logger = logging.getLogger(__name__)
 
@@ -32,7 +34,9 @@ class DatafeedLoopV1(AbstractDatafeedLoop):
 
     def __init__(self, datafeed_api, session_service, auth_session, config, repository=None):
         super().__init__(datafeed_api, session_service, auth_session, config)
-        self._datafeed_repository = OnDiskDatafeedIdRepository(config) if repository is None else repository
+        self._datafeed_repository = (
+            OnDiskDatafeedIdRepository(config) if repository is None else repository
+        )
         self._datafeed_id = None
 
     async def start(self):
@@ -57,8 +61,9 @@ class DatafeedLoopV1(AbstractDatafeedLoop):
     async def recreate_datafeed(self):
         session_token = await self._auth_session.session_token
         key_manager_token = await self._auth_session.key_manager_token
-        response = await self._datafeed_api.v4_datafeed_create_post(session_token=session_token,
-                                                                    key_manager_token=key_manager_token)
+        response = await self._datafeed_api.v4_datafeed_create_post(
+            session_token=session_token, key_manager_token=key_manager_token
+        )
         datafeed_id = response.id
         self._datafeed_repository.write(datafeed_id)
         self._datafeed_id = datafeed_id
@@ -73,17 +78,20 @@ class DatafeedLoopV1(AbstractDatafeedLoop):
     async def _read_datafeed(self):
         session_token = await self._auth_session.session_token
         key_manager_token = await self._auth_session.key_manager_token
-        events = await self._datafeed_api.v4_datafeed_id_read_get(id=self._datafeed_id,
-                                                                  session_token=session_token,
-                                                                  key_manager_token=key_manager_token)
+        events = await self._datafeed_api.v4_datafeed_id_read_get(
+            id=self._datafeed_id, session_token=session_token, key_manager_token=key_manager_token
+        )
         return events.value if events is not None and events.value else []
 
     async def _log_listener_exception(self, task):
         exception = task.exception()
         if exception:
             if isinstance(exception, EventError):
-                logger.warning("EventError occurred inside %s. "
-                               "EventError is not supported for DFv1, events will not get re-queued",
-                               task.get_name(), exc_info=exception)
+                logger.warning(
+                    "EventError occurred inside %s. "
+                    "EventError is not supported for DFv1, events will not get re-queued",
+                    task.get_name(),
+                    exc_info=exception,
+                )
             else:
                 logging.debug("Exception occurred inside %s", task.get_name(), exc_info=exception)
